==> znuny_6.5.15.orig.tar.gz: Znuny-rel-6_5_15/AUTHORS.md <==
The following persons contributed to Znuny:

* 1soproni <csaba@sopron.hu>
* akmet <akmet@users.noreply.github.com>
* Alex Kantchev <ak@otrs.com>
* Alex Mazur <alex.mazur@otrs.com>
* Alexandre D. Rogoski <alexandre@exatati.com.br>
* AM Mike <monitoring@amlogisticsolutions.de>
* André Brás <andre.bras@otrs.com>
* anonymous <unknown@anonymous>
* arlecchino <kolbma@users.noreply.github.com>
* b1-luettje <53084931+b1-luettje@users.noreply.github.com>
* Balazs Ur <balazs.ur@otrs.com>
* Balázs Úr <balazs.ur@otrs.com>
* Belnet <info@belnet.be>
* Bernhard Schmalhofer <Bernhard.Schmalhofer@gmx.de>
* Bodo Bauer <bodo.bauer@otrs.com>
* Burchard Steinbild <burchard.steinbild@otrs.com>
* Carlos Garcia <carlos.garcia@otrs.com>
* Carlos Rodriguez <carlos.rodriguez@otrs.com>
* Christian Schöpplein <christian.schoepplein@otrs.com>
* Christopher T. Kuhn <christopher.kuhn@otrs.com>
* Daniel Lisiecki <lisiecki.daniel@gmail.com>
* Daniel Sprenger <123074686+sprengerdaniel@users.noreply.github.com>
* Daniel Zamorano <daniel.zamorano@otrs.com>
* David Crimi <deathpoison.dc@gmail.com>
* Denis Nelubin <dnelubin@gmail.com>
* Dennis Schmelter <dennis.schmelter@otrs.com>
* Denny Korsukéwitz <dennykorsukewitz@gmail.com>
* Diego Selzlein <diegoselzlein@gmail.com>
* Dietmar Berg <dietmar.berg@thalesgroup.com>
* Dominik Klein <dominik.klein@otrs.com>
* Dusan Vuckovic <dusan.vuckovic@otrs.com>
* Elias Probst <elias.probst@otrs.com>
* Elva Novoa <elva.novoa@otrs.com>
* Emin Yazi <yazi@efflux.de>
* Enrique Matías Sánchez (Quique) <cronopios@gmail.com>
* Falko Saller <2903042+falkos@users.noreply.github.com>
* Felix Niklas <felix.niklas@otrs.com>
* Florian Edlhuber <florian.edlhuber@otrs.com>
* Florian Liebe <florian.liebe@otrs.com>
* Flávio Marta <7440579+CallMeFlanby@users.noreply.github.com>
* Friedrich Delgado <friedel@nomaden.org>
* Gerald Young <gerald.young@noynim.com>
* Henning Oschwald <henning.oschwald@otrs.com>
* Henrik Vetter <hv@znuny.com>
* IB Development Team <dev@ib.pl>
* Igor Djuric <igor.djuric@otrs.com>
* Jan Steinweg <jan.steinweg@otrs.com>
* Jaroslav Balaz <jaroslav.balaz@otrs.com>
* Jens Bothe <jens.bothe@otrs.com>
* Jens Pfeifer <jp@znuny.com>
* Johannes Hörburger <johannes.hoerburger@otrs.com>
* Johannes Nickel <jn@znuny.com>
* jsinagowitz <91074418+jsinagowitz@users.noreply.github.com>
* juanmclavero <juanm.clavero@ibsalut.es>
* Kai Herlemann <kh@znuny.com>
* Kamil Furtek <kfurtek@dev.opgksoftware.com>
* Keith Moore <tenareth@gmail.com>
* Kevin Janssen <77158891+BuTzZ@users.noreply.github.com>
* Konrad Gumienny <kgumienny@dev.opgksoftware.com>
* LotharZok <111051858+LotharZok@users.noreply.github.com>
* Luca Maranzano <liuk@linux.it>
* Lukas Bröring <lukas.broering@sectornord.de>
* Manuel Hecht <manuel.hecht@otrs.com>
* Marc Bonsels <marc.bonsels@otrs.com>
* Marc Nilius <marc.nilius@otrs.com>
* Marc Pahnke <89537707+MarcPahnke@users.noreply.github.com>
* Marco Buchholz <marco.buchholz@otrs.com>
* Marco Ferrante <marco@csita.unige.it>
* Markus Esche <markus.esche@otrs.com>
* Martha Pascual <martha.pascual@otrs.com>
* Martin Edenhofer <martin.edenhofer@otrs.com>
* Martin Gross <martin@pc-coholic.de>
* Martin Gruner <martin.gruner@otrs.com>
* Mathias Bräunling <mathias.braeunling@otrs.com>
* Matthias Bethke <mb@znuny.com>
* meisterheister <35762852+meisterheister@users.noreply.github.com>
* Michael Tänzer <neo@nhng.de>
* Michiel Beijen <michiel.beijen@otrs.com>
* Milan Rakic <mrakic@s7designcreative.com>
* Moritz Lenz <mlenz@noris.net>
* Never <never.min@gmail.com>
* NeverMin <never.min@gmail.com>
* Niels Dimmers <niels@nielsdimmers.nl>
* Niklas Schmitt <ns@znuny.com>
* Nils Fiedler <nils.fiedler@otrs.com>
* Nils Leideck <nils.leideck@otrs.com>
* Norihiro Tanaka <noritnk@kcn.ne.jp>
* Oberson Dylan <dylan.oberson@epfl.ch>
* Oliver Tappe <oliver.tappe@otrs.com>
* Olivier Sallou <olivier.sallou@irisa.fr>
* Patrick Brischler <patrick.brischler@otrs.com>
* Patrick Rauscher <prauscher@ohai.su>
* Paul Folkers <paul.folkers@sectornord.de>
* Paul Waring <paul@xk7.net>
* Paweł Bogusławski <pawel.boguslawski@ib.pl>
* Peter Krantz <peter@peterkrantz.se>
* Ralf Hildebrandt <hildeb@charite.de>
* Raphaël Doursenaud <rdoursenaud@gpcsolutions.fr>
* Renée Bäcker <info@perl-services.de>
* Richard Kammermayer <richard.kammermayer@otrs.com>
* Richard McCutchan <richard.mccutchan@otrs.com>
* Robin Naundorf <r.naundorf@fh-muenster.de>
* Rolf Schmidt <rolf.schmidt@otrs.com>
* Romain THERRAT <romain42@gmail.com>
* Roy Kaldung <rk@znuny.com>
* Rui Patinha <rui.patinha@otrs.com>
* s7design <otrs@s7designcreative.com>
* Sanjin Vik <svik@s7designcreative.com>
* sergot <filip@sergot.pl>
* Shawn Beasley <shawn.beasley@znuny.com>
* Stefan Bedorf <stefan.bedorf@otrs.com>
* Stefan Rother <stefan.rother@otrs.com>
* Stefan Wintermeyer <stefan@otrs.org>
* Steva Stevic <svik@s7designcreative.com>
* Sławomir Niedbała <slawnied1234@gmail.com>
* Theo van Hoesel <Th.J.v.Hoesel+GitHub@gmail.com>
* Thomas Raith <thomas.raith@otrs.com>
* Thomas Wouters <thomas@sijn.org>
* Thorsten Eckel <te@znuny.com>
* Tim Püttmanns <tim.puettmanns@maxence.de>
* Timo Gurr <timo.gurr@gmail.com>
* Torsten Thau <Torsten.Thau@cape-it.de>
* Udo Bretz <udo.bretz@otrs.com>
* Uwe Dieckmann <uwe.dieckmann@otrs.com>
* vlascoder <vlascoder@gmail.com>
* Walter Souto <walter.souto@saude.go.gov.br>
* Wojciech Kuchta <klapi85@gmail.com>
* Yuri Myasoedov <ymyasoedov@yandex.ru>
* Ziggy Trotter <142500923+ZTrotter@users.noreply.github.com>
* Znuny Weblate <do-not-reply@znuny.com>
* Zoran Ilibasic <zilibasic@s7designcreative.com>

==> znuny_6.5.16.orig.tar.gz: Znuny-rel-6_5_16/AUTHORS.md <==
The following persons contributed to Znuny:

* 1soproni <csaba@sopron.hu>
* akmet <akmet@users.noreply.github.com>
* Alex Kantchev <ak@otrs.com>
* Alex Mazur <alex.mazur@otrs.com>
* Alexandre D. Rogoski <alexandre@exatati.com.br>
* AM Mike <monitoring@amlogisticsolutions.de>
* André Brás <andre.bras@otrs.com>
* anonymous <unknown@anonymous>
* arlecchino <kolbma@users.noreply.github.com>
* b1-luettje <53084931+b1-luettje@users.noreply.github.com>
* Balazs Ur <balazs.ur@otrs.com>
* Balázs Úr <balazs.ur@otrs.com>
* Belnet <info@belnet.be>
* Bernhard Schmalhofer <Bernhard.Schmalhofer@gmx.de>
* Bodo Bauer <bodo.bauer@otrs.com>
* Burchard Steinbild <burchard.steinbild@otrs.com>
* Carlos Garcia <carlos.garcia@otrs.com>
* Carlos Rodriguez <carlos.rodriguez@otrs.com>
* Christian Schöpplein <christian.schoepplein@otrs.com>
* Christopher T. Kuhn <christopher.kuhn@otrs.com>
* Daniel Lisiecki <lisiecki.daniel@gmail.com>
* Daniel Sprenger <123074686+sprengerdaniel@users.noreply.github.com>
* Daniel Zamorano <daniel.zamorano@otrs.com>
* David Crimi <deathpoison.dc@gmail.com>
* Denis Nelubin <dnelubin@gmail.com>
* Dennis Schmelter <dennis.schmelter@otrs.com>
* Denny Korsukéwitz <dennykorsukewitz@gmail.com>
* Diego Selzlein <diegoselzlein@gmail.com>
* Dietmar Berg <dietmar.berg@thalesgroup.com>
* Dominik Klein <dominik.klein@otrs.com>
* DonMarlowne <184617043+DonMarlowne@users.noreply.github.com>
* Dusan Vuckovic <dusan.vuckovic@otrs.com>
* Elias Probst <elias.probst@otrs.com>
* Elva Novoa <elva.novoa@otrs.com>
* Emin Yazi <yazi@efflux.de>
* Enrique Matías Sánchez (Quique) <cronopios@gmail.com>
* Falko Saller <2903042+falkos@users.noreply.github.com>
* Felix Niklas <felix.niklas@otrs.com>
* Florian Edlhuber <florian.edlhuber@otrs.com>
* Florian Liebe <florian.liebe@otrs.com>
* Flávio Marta <7440579+CallMeFlanby@users.noreply.github.com>
* Friedrich Delgado <friedel@nomaden.org>
* Gerald Young <gerald.young@noynim.com>
* Henning Oschwald <henning.oschwald@otrs.com>
* Henrik Vetter <hv@znuny.com>
* IB Development Team <dev@ib.pl>
* Igor Djuric <igor.djuric@otrs.com>
* Jan Steinweg <jan.steinweg@otrs.com>
* Jaroslav Balaz <jaroslav.balaz@otrs.com>
* Jens Bothe <jens.bothe@otrs.com>
* Jens Pfeifer <jp@znuny.com>
* Johannes Hörburger <johannes.hoerburger@otrs.com>
* Johannes Nickel <jn@znuny.com>
* jsinagowitz <91074418+jsinagowitz@users.noreply.github.com>
* juanmclavero <juanm.clavero@ibsalut.es>
* Kai Herlemann <kh@znuny.com>
* Kamil Furtek <kfurtek@dev.opgksoftware.com>
* Keith Moore <tenareth@gmail.com>
* Kevin Janssen <77158891+BuTzZ@users.noreply.github.com>
* Konrad Gumienny <kgumienny@dev.opgksoftware.com>
* LotharZok <111051858+LotharZok@users.noreply.github.com>
* Luca Maranzano <liuk@linux.it>
* Lukas Bröring <lukas.broering@sectornord.de>
* Manuel Hecht <manuel.hecht@otrs.com>
* Marc Bonsels <marc.bonsels@otrs.com>
* Marc Nilius <marc.nilius@otrs.com>
* Marc Pahnke <89537707+MarcPahnke@users.noreply.github.com>
* Marco Buchholz <marco.buchholz@otrs.com>
* Marco Ferrante <marco@csita.unige.it>
* Markus Esche <markus.esche@otrs.com>
* Martha Pascual <martha.pascual@otrs.com>
* Martin Edenhofer <martin.edenhofer@otrs.com>
* Martin Gross <martin@pc-coholic.de>
* Martin Gruner <martin.gruner@otrs.com>
* Mathias Bräunling <mathias.braeunling@otrs.com>
* Matthias Bethke <mb@znuny.com>
* meisterheister <35762852+meisterheister@users.noreply.github.com>
* Michael Tänzer <neo@nhng.de>
* Michiel Beijen <michiel.beijen@otrs.com>
* Milan Rakic <mrakic@s7designcreative.com>
* Moritz Lenz <mlenz@noris.net>
* Never <never.min@gmail.com>
* NeverMin <never.min@gmail.com>
* Niels Dimmers <niels@nielsdimmers.nl>
* Niklas Schmitt <ns@znuny.com>
* Nils Fiedler <nils.fiedler@otrs.com>
* Nils Leideck <nils.leideck@otrs.com>
* Norihiro Tanaka <noritnk@kcn.ne.jp>
* Oberson Dylan <dylan.oberson@epfl.ch>
* Oliver Tappe <oliver.tappe@otrs.com>
* Olivier Sallou <olivier.sallou@irisa.fr>
* Patrick Brischler <patrick.brischler@otrs.com>
* Patrick Rauscher <prauscher@ohai.su>
* Paul Folkers <paul.folkers@sectornord.de>
* Paul Waring <paul@xk7.net>
* Paweł Bogusławski <pawel.boguslawski@ib.pl>
* Peter Krantz <peter@peterkrantz.se>
* Ralf Hildebrandt <hildeb@charite.de>
* Raphaël Doursenaud <rdoursenaud@gpcsolutions.fr>
* Renée Bäcker <info@perl-services.de>
* Richard Kammermayer <richard.kammermayer@otrs.com>
* Richard McCutchan <richard.mccutchan@otrs.com>
* Robin Naundorf <r.naundorf@fh-muenster.de>
* Rolf Schmidt <rolf.schmidt@otrs.com>
* Romain THERRAT <romain42@gmail.com>
* Roy Kaldung <rk@znuny.com>
* Rui Patinha <rui.patinha@otrs.com>
* s7design <otrs@s7designcreative.com>
* Sanjin Vik <svik@s7designcreative.com>
* sergot <filip@sergot.pl>
* Shawn Beasley <shawn.beasley@znuny.com>
* Stefan Bedorf <stefan.bedorf@otrs.com>
* Stefan Rother <stefan.rother@otrs.com>
* Stefan Wintermeyer <stefan@otrs.org>
* Steva Stevic <svik@s7designcreative.com>
* Sławomir Niedbała <slawnied1234@gmail.com>
* Theo van Hoesel <Th.J.v.Hoesel+GitHub@gmail.com>
* Thomas Raith <thomas.raith@otrs.com>
* Thomas Wouters <thomas@sijn.org>
* Thorsten Eckel <te@znuny.com>
* Tim Püttmanns <tim.puettmanns@maxence.de>
* Timo Gurr <timo.gurr@gmail.com>
* Torsten Thau <Torsten.Thau@cape-it.de>
* Udo Bretz <udo.bretz@otrs.com>
* Uwe Dieckmann <uwe.dieckmann@otrs.com>
* vlascoder <vlascoder@gmail.com>
* Walter Souto <walter.souto@saude.go.gov.br>
* Wojciech Kuchta <klapi85@gmail.com>
* Yuri Myasoedov <ymyasoedov@yandex.ru>
* Zigfield Trotter <zt@znuny.com>
* Znuny Weblate <do-not-reply@znuny.com>
* Zoran Ilibasic <zilibasic@s7designcreative.com>
